==> servicecatalog-model-6.3.0-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBindingListFluent.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ServiceBindingListFluent<A extends ServiceBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ServiceBinding item);
  public A setToItems(Integer index,ServiceBinding item);
  public A addToItems(io.fabric8.servicecatalog.api.model.ServiceBinding... items);
  public A addAllToItems(Collection<ServiceBinding> items);
  public A removeFromItems(io.fabric8.servicecatalog.api.model.ServiceBinding... items);
  public A removeAllFromItems(Collection<ServiceBinding> items);
  public A removeMatchingFromItems(Predicate<ServiceBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServiceBinding> getItems();
  public List<ServiceBinding> buildItems();
  public ServiceBinding buildItem(Integer index);
  public ServiceBinding buildFirstItem();
  public ServiceBinding buildLastItem();
  public ServiceBinding buildMatchingItem(Predicate<ServiceBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ServiceBindingBuilder> predicate);
  public A withItems(List<ServiceBinding> items);
  public A withItems(io.fabric8.servicecatalog.api.model.ServiceBinding... items);
  public Boolean hasItems();
  public ServiceBindingListFluent.ItemsNested<A> addNewItem();
  public ServiceBindingListFluent.ItemsNested<A> addNewItemLike(ServiceBinding item);
  public ServiceBindingListFluent.ItemsNested<A> setNewItemLike(Integer index,ServiceBinding item);
  public ServiceBindingListFluent.ItemsNested<A> editItem(Integer index);
  public ServiceBindingListFluent.ItemsNested<A> editFirstItem();
  public ServiceBindingListFluent.ItemsNested<A> editLastItem();
  public ServiceBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ServiceBindingFluent<ServiceBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBindingListFluent.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ServiceBindingListFluent<A extends ServiceBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ServiceBinding item);
  public A setToItems(int index,ServiceBinding item);
  public A addToItems(io.fabric8.servicecatalog.api.model.ServiceBinding... items);
  public A addAllToItems(Collection<ServiceBinding> items);
  public A removeFromItems(io.fabric8.servicecatalog.api.model.ServiceBinding... items);
  public A removeAllFromItems(Collection<ServiceBinding> items);
  public A removeMatchingFromItems(Predicate<ServiceBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServiceBinding> getItems();
  public List<ServiceBinding> buildItems();
  public ServiceBinding buildItem(int index);
  public ServiceBinding buildFirstItem();
  public ServiceBinding buildLastItem();
  public ServiceBinding buildMatchingItem(Predicate<ServiceBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ServiceBindingBuilder> predicate);
  public A withItems(List<ServiceBinding> items);
  public A withItems(io.fabric8.servicecatalog.api.model.ServiceBinding... items);
  public Boolean hasItems();
  public ServiceBindingListFluent.ItemsNested<A> addNewItem();
  public ServiceBindingListFluent.ItemsNested<A> addNewItemLike(ServiceBinding item);
  public ServiceBindingListFluent.ItemsNested<A> setNewItemLike(int index,ServiceBinding item);
  public ServiceBindingListFluent.ItemsNested<A> editItem(int index);
  public ServiceBindingListFluent.ItemsNested<A> editFirstItem();
  public ServiceBindingListFluent.ItemsNested<A> editLastItem();
  public ServiceBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ServiceBindingFluent<ServiceBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
